# Changelog

## [0.3.2a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.3.2a1) (2024-12-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.3.1...0.3.2a1)

**Merged pull requests:**

- fix: pull padatious fixes from ovos-padatious-pipeline-plugin/pul/l26 [\#625](https://github.com/OpenVoiceOS/ovos-core/pull/625) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
